@@ -1,5 +1,5 @@
 package Net::Kubernetes::Resource::ServiceAccount;
-$Net::Kubernetes::Resource::ServiceAccount::VERSION = '1.06';
+$Net::Kubernetes::Resource::ServiceAccount::VERSION = '1.07';
 # ABSTRACT: Object representatioon of a Kubernetes service account
 
 use Moose;
@@ -7,15 +7,24 @@ use Moose;
 extends 'Net::Kubernetes::Resource';
 
 has secrets => (
-    is  => 'ro',
-    isa => 'ArrayRef[HashRef]',
+    is  => 'rw',
+    isa => 'ArrayRef',
 );
 
 has imagePullSecrets => (
-    is  => 'ro',
-    isa => 'ArrayRef[HashRef]',
+    is  => 'rw',
+    isa => 'ArrayRef',
 );
 
+augment 'as_hashref' => sub {
+	my $self = shift;
+
+	return (
+		secrets          => $self->secrets,
+		imagePullSecrets => $self->imagePullSecrets,
+	);
+};
+
 return 42;
 
 __END__
@@ -30,7 +39,7 @@ Net::Kubernetes::Resource::ServiceAccount - Object representatioon of a Kubernet
 
 =head1 VERSION
 
-version 1.06
+version 1.07
 
 =head1 AUTHOR
 
